agentle.mcp.errors
==================

.. automodule:: agentle.mcp.errors

   
   .. rubric:: Classes

   .. autosummary::
   
      ErrorCode
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   error_code
